==> kdeutils-4.2.0.tar.bz2: kdeutils-4.2.0/okteta/core/piecetable/tests/swaprangespiecetablechangeabstractpiecetablechangeiftest.cpp <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "swaprangespiecetablechangeabstractpiecetablechangeiftest.h"

// test object
#include <piecetable/swaprangespiecetablechange.h>
// lib
#include <piecetable/piecetable.h>
// Qt
#include <QtTest/QtTest>


static const int FirstRangeStart = 30;
static const int SecondRangeStart = 50;
static const int SecondRangeEnd = 66;

namespace KPieceTable
{

AbstractPieceTableChange *SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest::createPieceTableChange()
{
    SwapRangesPieceTableChange *pieceTableChange =
        new SwapRangesPieceTableChange( FirstRangeStart, KHE::Section(SecondRangeStart,SecondRangeEnd) );

    return pieceTableChange;
}
void SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest::changePieceTable( PieceTable *pieceTable )
{
    pieceTable->swap( FirstRangeStart, KHE::Section(SecondRangeStart,SecondRangeEnd) );
}

void SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest::deletePieceTableChange( AbstractPieceTableChange *pieceTableChange )
{
    delete pieceTableChange;
}

}

QTEST_MAIN( KPieceTable::SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest )

==> kdeutils-4.4.0.tar.bz2: kdeutils-4.4.0/okteta/core/piecetable/tests/swaprangespiecetablechangeabstractpiecetablechangeiftest.cpp <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "swaprangespiecetablechangeabstractpiecetablechangeiftest.h"

// test object
#include <piecetable/swaprangespiecetablechange.h>
// lib
#include <piecetable/piecetable.h>
// Qt
#include <QtTest/QtTest>


namespace KPieceTable
{

static const Address FirstRangeStart = 30;
static const Address SecondRangeStart = 50;
static const Address SecondRangeEnd = 66;


AbstractPieceTableChange* SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest::createPieceTableChange()
{
    SwapRangesPieceTableChange* pieceTableChange =
        new SwapRangesPieceTableChange( FirstRangeStart, AddressRange(SecondRangeStart,SecondRangeEnd) );

    return pieceTableChange;
}

void SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest::changePieceTable( PieceTable* pieceTable )
{
    pieceTable->swap( FirstRangeStart, AddressRange(SecondRangeStart,SecondRangeEnd) );
}

void SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest::deletePieceTableChange( AbstractPieceTableChange* pieceTableChange )
{
    delete pieceTableChange;
}

}

QTEST_MAIN( KPieceTable::SwapRangesPieceTableChangeAbstractPieceTableChangeIfTest )
